@@ -54,8 +54,8 @@ class Config(object):
         r'''
         import essential files and set essential interfaces for link prediction
         '''
-        # self.lib.importTestFiles()
-        # self.lib.importTypeFiles()
+        self.lib.importTestFiles()
+        self.lib.importTypeFiles()
         self.test_h = np.zeros(self.lib.getEntityTotal(), dtype=np.int64)
         self.test_t = np.zeros(self.lib.getEntityTotal(), dtype=np.int64)
         self.test_r = np.zeros(self.lib.getEntityTotal(), dtype=np.int64)
@@ -112,6 +112,7 @@ class Config(object):
             self.trainTotal = self.lib.getTrainTotal()
             self.testTotal = self.lib.getTestTotal()
             self.validTotal = self.lib.getValidTotal()
+            print(self.relTotal, self.entTotal, self.trainTotal, self.testTotal, self.validTotal)
             self.batch_size = int(self.lib.getTrainTotal() / self.nbatches)
             self.batch_seq_size = self.batch_size * (1 + self.negative_ent + self.negative_rel)
             self.batch_h = np.zeros(self.batch_size * (1 + self.negative_ent + self.negative_rel), dtype=np.int64)
@@ -354,36 +355,69 @@ class Config(object):
                     self.ckpt.save(self.exportName + 'ckpt')
                 if self.out_path != None:
                     self.save_parameters(self.out_path)
-
     def test(self):
         with self.graph.as_default():
             with self.sess.as_default():
                 if self.importName != None:
-                    self.restore_tensorflow()
+                        self.restore_tensorflow()
                 if self.test_link_prediction:
-                    total = self.lib.getTestTotal()
-                    for times in range(20):
-                        self.lib.getHeadBatch(self.test_h_addr, self.test_t_addr, self.test_r_addr)
-                        res = self.test_step(self.test_h, self.test_t, self.test_r)
-                        self.lib.testHead(res.__array_interface__['data'][0])
+                        total = self.lib.getTestTotal()
+                        for times in range(total):
+                            self.lib.getHeadBatch(self.test_h_addr, self.test_t_addr, self.test_r_addr)
+                            res = self.test_step(self.test_h, self.test_t, self.test_r)
+                            self.lib.testHead(res.__array_interface__['data'][0])
 
-                        self.lib.getTailBatch(self.test_h_addr, self.test_t_addr, self.test_r_addr)
-                        res = self.test_step(self.test_h, self.test_t, self.test_r)
-                        self.lib.testTail(res.__array_interface__['data'][0])
-                        if self.log_on:
-                            print(times)
-                    self.lib.test_link_prediction()
+                            self.lib.getTailBatch(self.test_h_addr, self.test_t_addr, self.test_r_addr)
+                            res = self.test_step(self.test_h, self.test_t, self.test_r)
+                            self.lib.testTail(res.__array_interface__['data'][0])
+                            if self.log_on:
+                                print(times)
+                                self.lib.test_link_prediction()
                 if self.test_triple_classification:
-                    self.lib.getValidBatch(self.valid_pos_h_addr, self.valid_pos_t_addr, self.valid_pos_r_addr, self.valid_neg_h_addr, self.valid_neg_t_addr, self.valid_neg_r_addr)
-                    res_pos = self.test_step(self.valid_pos_h, self.valid_pos_t, self.valid_pos_r)
-                    res_neg = self.test_step(self.valid_neg_h, self.valid_neg_t, self.valid_neg_r)
-                    self.lib.getBestThreshold(self.relThresh_addr, res_pos.__array_interface__['data'][0], res_neg.__array_interface__['data'][0])
+                        self.lib.getValidBatch(self.valid_pos_h_addr, self.valid_pos_t_addr, self.valid_pos_r_addr, self.valid_neg_h_addr, self.valid_neg_t_addr, self.valid_neg_r_addr)
+                        res_pos = self.test_step(self.valid_pos_h, self.valid_pos_t, self.valid_pos_r)
+                        res_neg = self.test_step(self.valid_neg_h, self.valid_neg_t, self.valid_neg_r)
+                        self.lib.getBestThreshold(self.relThresh_addr, res_pos.__array_interface__['data'][0], res_neg.__array_interface__['data'][0])
 
-                    self.lib.getTestBatch(self.test_pos_h_addr, self.test_pos_t_addr, self.test_pos_r_addr, self.test_neg_h_addr, self.test_neg_t_addr, self.test_neg_r_addr)
+                        self.lib.getTestBatch(self.test_pos_h_addr, self.test_pos_t_addr, self.test_pos_r_addr, self.test_neg_h_addr, self.test_neg_t_addr, self.test_neg_r_addr)
 
-                    res_pos = self.test_step(self.test_pos_h, self.test_pos_t, self.test_pos_r)
-                    res_neg = self.test_step(self.test_neg_h, self.test_neg_t, self.test_neg_r)
-                    self.lib.test_triple_classification(self.relThresh_addr, res_pos.__array_interface__['data'][0], res_neg.__array_interface__['data'][0])
+                        res_pos = self.test_step(self.test_pos_h, self.test_pos_t, self.test_pos_r)
+                        res_neg = self.test_step(self.test_neg_h, self.test_neg_t, self.test_neg_r)
+                        self.lib.test_triple_classification(self.relThresh_addr, res_pos.__array_interface__['data'][0], res_neg.__array_interface__['data'][0])
+    # def test(self):
+    #     with self.graph.as_default():
+    #         with self.sess.as_default():
+    #             if self.importName != None:
+    #                 self.restore_tensorflow()
+    #             if self.test_link_prediction:
+    #                 total = self.lib.getTestTotal()
+    #                 for times in range(total):
+    #                     print(self.test_h_addr, self.test_t_addr, self.test_r_addr)
+    #                     print(total, self.test_h)
+    #                     self.lib.getHeadBatch(self.test_h_addr, self.test_t_addr, self.test_r_addr)
+    #                     print(self.test_h, self.test_t)
+    #                     res = self.test_step(self.test_h, self.test_t, self.test_r)
+    #                     print("foo")
+    #                     self.lib.testHead(res.__array_interface__['data'][0])
+    #                     print("bar")
+
+    #                     self.lib.getTailBatch(self.test_h_addr, self.test_t_addr, self.test_r_addr)
+    #                     res = self.test_step(self.test_h, self.test_t, self.test_r)
+    #                     self.lib.testTail(res.__array_interface__['data'][0])
+    #                     if self.log_on:
+    #                         print(times)
+    #                 self.lib.test_link_prediction()
+    #             if self.test_triple_classification:
+    #                 self.lib.getValidBatch(self.valid_pos_h_addr, self.valid_pos_t_addr, self.valid_pos_r_addr, self.valid_neg_h_addr, self.valid_neg_t_addr, self.valid_neg_r_addr)
+    #                 res_pos = self.test_step(self.valid_pos_h, self.valid_pos_t, self.valid_pos_r)
+    #                 res_neg = self.test_step(self.valid_neg_h, self.valid_neg_t, self.valid_neg_r)
+    #                 self.lib.getBestThreshold(self.relThresh_addr, res_pos.__array_interface__['data'][0], res_neg.__array_interface__['data'][0])
+
+    #                 self.lib.getTestBatch(self.test_pos_h_addr, self.test_pos_t_addr, self.test_pos_r_addr, self.test_neg_h_addr, self.test_neg_t_addr, self.test_neg_r_addr)
+
+    #                 res_pos = self.test_step(self.test_pos_h, self.test_pos_t, self.test_pos_r)
+    #                 res_neg = self.test_step(self.test_neg_h, self.test_neg_t, self.test_neg_r)
+    #                 self.lib.test_triple_classification(self.relThresh_addr, res_pos.__array_interface__['data'][0], res_neg.__array_interface__['data'][0])
 
     def predict_head_entity(self, t, r, k):
         r'''This mothod predicts the top k head entities given tail entity and relation.
